@@ -5,7 +5,7 @@ test_that("formatEstimateName", {
   # input 1 ----
   result_output <-  formatEstimateName(result,
                                        estimateNameFormat = c("N (%)" = "<count> (<percentage>%)",
-                                                  "N" = "<count>"),
+                                                              "N" = "<count>"),
                                        keepNotFormatted = TRUE)
   # check count as "N"
   expect_identical(unique(result_output$estimate_name[result_output$variable_name == "number subjects"]),
@@ -34,11 +34,14 @@ test_that("formatEstimateName", {
                      " (",
                      estimates_in$estimate_value[estimates_in$variable_name == "Medications" &  estimates_in$estimate_name == "percentage"],
                      "%)"))
+  # attributes mantained:
+  expect_true(nrow(omopgenerics::settings(result_output)) == 1)
+  expect_true(inherits(result_output, "summarised_result"))
 
   # input 2 ----
   result_output <-  formatEstimateName(result,
                                        estimateNameFormat = c("<mean> (<sd>)",
-                                                  "N%" = "<count> (<percentage> %)"),
+                                                              "N%" = "<count> (<percentage> %)"),
                                        keepNotFormatted = FALSE)
   # Check not keep formatted
   expect_true(result_output |>
@@ -69,13 +72,15 @@ test_that("formatEstimateName", {
                      estimates_in$estimate_value[estimates_in$variable_name == "Medications" &  estimates_in$estimate_name == "percentage"],
                      " %)"))
   # Input 3 ----
-  expect_warning(expect_warning(result_output <- formatEstimateName(
-    result,
-    estimateNameFormat = c("N (%)" = "<count> (<notAKey>%)",
-                           "N" = "<count>",
-                           "<alsoNotAkey>",
-                           "%" = "<percentage>"),
-    keepNotFormatted = FALSE), "has not been formatted."), "has not been formatted.")
+  expect_message(expect_message(
+    result_output <- formatEstimateName(
+      result,
+      estimateNameFormat = c("N (%)" = "<count> (<notAKey>%)",
+                             "N" = "<count>",
+                             "<alsoNotAkey>",
+                             "%" = "<percentage>"),
+      keepNotFormatted = FALSE)
+  ))
   # check count as "N"
   expect_identical(unique(result_output$estimate_name[result_output$variable_name == "number subjects"]),
                    "N")
@@ -106,21 +111,31 @@ test_that("formatEstimateName", {
     useFormatOrder = TRUE)
   expect_true(is.na(res$estimate_value[1]))
 
+  # Class ----
+  expect_true(inherits(res, "summarised_result"))
+  class(result) <- c("tbl_df", "tbl", "data.frame")
+  res <- formatEstimateName(
+    result,
+    estimateNameFormat = "<mean> (<sd>)",
+    keepNotFormatted = TRUE,
+    useFormatOrder = TRUE)
+  expect_false(inherits(res, "summarised_result"))
+
   # Wrong input ----
   expect_error(result |> dplyr::select(-"estimate_name") |> formatEstimateName())
   expect_error(formatEstimateName(result,
                                   estimateNameFormat = c("N" = "count",
                                                          "N (%)" = "count (percentage%)"),
                                   keepNotFormatted = FALSE))
-  expect_warning(formatEstimateName(result,
+  expect_message(formatEstimateName(result,
                                     estimateNameFormat = c("N" = "<count>",
                                                            "N (%)" = "count (<lala>%)"),
                                     keepNotFormatted = TRUE),
                  "has not been formatted.")
-  expect_warning(formatEstimateName(result,
-                     estimateNameFormat = c("N" = "count",
-                                            "N (%)" = "<count> (<percentage>%)"),
-                     keepNotFormatted = FALSE),
+  expect_message(formatEstimateName(result,
+                                    estimateNameFormat = c("N" = "count",
+                                                           "N (%)" = "<count> (<percentage>%)"),
+                                    keepNotFormatted = FALSE),
                  "does not contain an estimate name indicated by <...>")
   expect_error(formatEstimateName(result,
                                   estimateNameFormat = NA,
@@ -132,10 +147,6 @@ test_that("formatEstimateName, useFormatOrder", {
     # number subjects
     dplyr::tibble(
       "cdm_name" = "mock",
-      "result_type" = NA_character_,
-      "package_name" = "visOmopResults",
-      "package_version" = utils::packageVersion("visOmopResults") |>
-        as.character(),
       "group_name" = "cohort_name",
       "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
       "strata_name" = rep(c(
@@ -157,10 +168,6 @@ test_that("formatEstimateName, useFormatOrder", {
       # age - mean
       dplyr::tibble(
         "cdm_name" = "mock",
-        "result_type" = NA_character_,
-        "package_name" = "visOmopResults",
-        "package_version" = utils::packageVersion("visOmopResults") |>
-          as.character(),
         "group_name" = "cohort_name",
         "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
         "strata_name" = rep(c(
@@ -183,10 +190,6 @@ test_that("formatEstimateName, useFormatOrder", {
       # age - mean
       dplyr::tibble(
         "cdm_name" = "mock",
-        "result_type" = NA_character_,
-        "package_name" = "visOmopResults",
-        "package_version" = utils::packageVersion("visOmopResults") |>
-          as.character(),
         "group_name" = "cohort_name",
         "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
         "strata_name" = rep(c(
@@ -209,10 +212,6 @@ test_that("formatEstimateName, useFormatOrder", {
     dplyr::union_all(
       dplyr::tibble(
         "cdm_name" = "mock",
-        "result_type" = NA_character_,
-        "package_name" = "visOmopResults",
-        "package_version" = utils::packageVersion("visOmopResults") |>
-          as.character(),
         "group_name" = "cohort_name",
         "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
         "strata_name" = rep(c(
@@ -232,7 +231,15 @@ test_that("formatEstimateName, useFormatOrder", {
       )
     ) |>
     dplyr::mutate(result_id = "1") |>
-    omopgenerics::newSummarisedResult()
+    omopgenerics::newSummarisedResult(
+      settings = dplyr::tibble(
+        "result_id" = as.integer(1),
+        "result_type" = "mock_test",
+        "package_name" = "visOmopResults",
+        "package_version" = utils::packageVersion("visOmopResults") |>
+          as.character(),
+      )
+    )
 
   # FALSE ----
   result_output <-  formatEstimateName(result,
@@ -256,11 +263,11 @@ test_that("formatEstimateName, useFormatOrder", {
                                        useFormatOrder = TRUE)
 
   expect_false(any(which(result_output$estimate_name %in% "range") <
-                    which(result_output$estimate_name %in% "mean")))
+                     which(result_output$estimate_name %in% "mean")))
   expect_false(any(which(result_output$estimate_name %in% "number subjets") <
-                    which(result_output$estimate_name %in% "mean")))
+                     which(result_output$estimate_name %in% "mean")))
   expect_false(any(which(result_output$estimate_name %in% "number subjets") <
-                    which(result_output$estimate_name %in% "range")))
+                     which(result_output$estimate_name %in% "range")))
 
 })
 
@@ -282,3 +289,108 @@ test_that("empty format",{
   expect_identical(res1, result)
 })
 
+
+test_that("not a summarised result",{
+  result <- dplyr::tibble(
+    variable = "variable",
+    estimate_type = c("integer", "numeric"),
+    estimate_name = c("count", "percentage"),
+    estimate_value = c("100", "50.1")
+  )
+  res0 <- formatEstimateName(
+    result,
+    estimateNameFormat = c("N (%)" = "<count> (<percentage>%)")
+  )
+  expect_true(nrow(res0) == 1)
+  expect_equal(class(result), class(res0))
+})
+
+test_that("common key word",{
+  result <- dplyr::tibble(
+    "cdm_name" = "mock",
+    "group_name" = "cohort_name",
+    "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
+    "strata_name" = rep(c(
+      "overall", rep("age_group &&& sex", 4), rep("sex", 2), rep("age_group", 2)
+    ), 2),
+    "strata_level" = rep(c(
+      "overall", "<40 &&& Male", ">=40 &&& Male", "<40 &&& Female",
+      ">=40 &&& Female", "Male", "Female", "<40", ">=40"
+    ), 2),
+    "variable_name" = "number subjects",
+    "variable_level" = NA_character_,
+    "estimate_name" = "count",
+    "estimate_type" = "integer",
+    "estimate_value" = round(10000000*stats::runif(18)) |> as.character(),
+    "additional_name" = "overall",
+    "additional_level" = "overall"
+  ) |>
+    # age - mean
+    dplyr::union_all(
+      dplyr::tibble(
+        "cdm_name" = "mock",
+        "group_name" = "cohort_name",
+        "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
+        "strata_name" = rep(c(
+          "overall", rep("age_group &&& sex", 4), rep("sex", 2), rep("age_group", 2)
+        ), 2),
+        "strata_level" = rep(c(
+          "overall", "<40 &&& Male", ">=40 &&& Male", "<40 &&& Female",
+          ">=40 &&& Female", "Male", "Female", "<40", ">=40"
+        ), 2),
+        "variable_name" = "number subjects",
+        "variable_level" = NA_character_,
+        "estimate_name" = "count_95CI_lower",
+        "estimate_type" = "integer",
+        "estimate_value" = round(10000000*stats::runif(18)) |> as.character(),
+        "additional_name" = "overall",
+        "additional_level" = "overall"
+      )
+    )
+  res <- formatEstimateName(result, estimateNameFormat = "<count> <count_95CI_lower>")
+  expect_true(unique(res$estimate_name) == "count count_95CI_lower")
+
+  result <- dplyr::tibble(
+    "cdm_name" = "mock",
+    "group_name" = "cohort_name",
+    "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
+    "strata_name" = rep(c(
+      "overall", rep("age_group &&& sex", 4), rep("sex", 2), rep("age_group", 2)
+    ), 2),
+    "strata_level" = rep(c(
+      "overall", "<40 &&& Male", ">=40 &&& Male", "<40 &&& Female",
+      ">=40 &&& Female", "Male", "Female", "<40", ">=40"
+    ), 2),
+    "variable_name" = "number subjects",
+    "variable_level" = NA_character_,
+    "estimate_name" = "count",
+    "estimate_type" = "integer",
+    "estimate_value" = round(10000000*stats::runif(18)) |> as.character(),
+    "additional_name" = "overall",
+    "additional_level" = "overall"
+  ) |>
+    # age - mean
+    dplyr::union_all(
+      dplyr::tibble(
+        "cdm_name" = "mock",
+        "group_name" = "cohort_name",
+        "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
+        "strata_name" = rep(c(
+          "overall", rep("age_group &&& sex", 4), rep("sex", 2), rep("age_group", 2)
+        ), 2),
+        "strata_level" = rep(c(
+          "overall", "<40 &&& Male", ">=40 &&& Male", "<40 &&& Female",
+          ">=40 &&& Female", "Male", "Female", "<40", ">=40"
+        ), 2),
+        "variable_name" = "number subjects",
+        "variable_level" = NA_character_,
+        "estimate_name" = "95CI_lower_count",
+        "estimate_type" = "integer",
+        "estimate_value" = round(10000000*stats::runif(18)) |> as.character(),
+        "additional_name" = "overall",
+        "additional_level" = "overall"
+      )
+    )
+  res <- formatEstimateName(result, estimateNameFormat = "<count> <95CI_lower_count>")
+  expect_true(unique(res$estimate_name) == "count 95CI_lower_count")
+})
