@@ -22,8 +22,8 @@ test_that("fxTable", {
     title = "Test 1",
     subtitle = NULL,
     caption = NULL,
-    groupNameCol = NULL,
-    groupNameAsColumn = FALSE,
+    groupColumn = NULL,
+    groupAsColumn = FALSE,
     groupOrder = NULL
   )
 
@@ -41,9 +41,6 @@ test_that("fxTable", {
   expect_equal(fxResult$header$styles$text$bold$data[, "cdm_name"] |> unique(), TRUE)
   expect_equal(fxResult$header$styles$text$color$data[, "cdm_name"][1], "blue")
 
-  # na
-  expect_equal(fxResult$body$dataset$result_type |> unique(), "mock_summarised_result")
-
   # default fxTable format
   expect_equal(fxResult$body$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), 1)
   expect_equal(fxResult$body$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "gray")
@@ -53,12 +50,12 @@ test_that("fxTable", {
   expect_null(fxResult$caption$value)
 
   # Alignment
-  expect_equal(fxResult$body$styles$pars$text.align$data[1,12:29] |> unique(), "right")
-  expect_equal(fxResult$body$styles$pars$text.align$data[3,12:29] |> unique(), "right")
-  expect_equal(fxResult$body$styles$pars$text.align$data[5,12:29] |> unique(), "right")
-  expect_equal(fxResult$body$styles$pars$text.align$data[1,1:11] |> unique(), "left")
-  expect_equal(fxResult$body$styles$pars$text.align$data[3,1:11] |> unique(), "left")
-  expect_equal(fxResult$body$styles$pars$text.align$data[5,1:11] |> unique(), "left")
+  expect_equal(fxResult$body$styles$pars$text.align$data[1,9:26] |> unique(), "right")
+  expect_equal(fxResult$body$styles$pars$text.align$data[3,9:26] |> unique(), "right")
+  expect_equal(fxResult$body$styles$pars$text.align$data[5,9:26] |> unique(), "right")
+  expect_equal(fxResult$body$styles$pars$text.align$data[1,1:8] |> unique(), "left")
+  expect_equal(fxResult$body$styles$pars$text.align$data[3,1:8] |> unique(), "left")
+  expect_equal(fxResult$body$styles$pars$text.align$data[5,1:8] |> unique(), "left")
 
   # Input 2 ----
   table_to_format <- mockSummarisedResult() |>
@@ -80,8 +77,8 @@ test_that("fxTable", {
     title = "Title test 2",
     subtitle = "Subtitle for test 2",
     caption = "*This* is the caption",
-    groupNameCol = "group_level",
-    groupNameAsColumn = FALSE,
+    groupColumn = "group_level",
+    groupAsColumn = FALSE,
     groupOrder = NULL
   )
 
@@ -101,9 +98,6 @@ test_that("fxTable", {
   expect_equal(fxResult$header$styles$text$color$data[, "strata_name\nage_group\nstrata_level\n>=40"],
                c("black", "blue", "white", "black", "white", "black"))
 
-  # na
-  expect_equal(fxResult$body$dataset$result_type |> unique(), c(NA, "mock_summarised_result"))
-
   # body
   expect_equal(fxResult$body$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(0,1))
   expect_equal(fxResult$body$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "black")
@@ -116,9 +110,9 @@ test_that("fxTable", {
   expect_equal(fxResult$caption$value, "*This* is the caption")
 
   # group label
-  expect_equal(fxResult$body$spans$rows[1,], c(1, 20, rep(0, 19)))
-  expect_equal(fxResult$body$spans$rows[7,], c(1, 20, rep(0, 19)))
-  expect_equal(fxResult$body$spans$rows[3,], rep(1, 21))
+  expect_equal(fxResult$body$spans$rows[1,], c(1, 17, rep(0, 16)))
+  expect_equal(fxResult$body$spans$rows[7,], c(1, 17, rep(0, 16)))
+  expect_equal(fxResult$body$spans$rows[3,], rep(1, 18))
 
   # Input 3 ----
   table_to_format <- mockSummarisedResult() |>
@@ -141,15 +135,15 @@ test_that("fxTable", {
     title = "Title test 2",
     subtitle = "Subtitle for test 2",
     caption = "*This* is the caption",
-    groupNameCol = "group_level",
-    groupNameAsColumn = TRUE,
+    groupColumn = "group_level",
+    groupAsColumn = TRUE,
     groupOrder = c("cohort2", "cohort1")
   )
 
   # group label
   expect_equal(fxResult$body$spans$columns[,1], c(5, rep(0,4), 5, rep(0,4)))
   expect_equal(fxResult$body$dataset[,1] |>  levels(), c("cohort2", "cohort1"))
-  expect_equal(fxResult$body$spans$rows[3,], rep(1, 21))
+  expect_equal(fxResult$body$spans$rows[3,], rep(1, 18))
   expect_equal(fxResult$body$styles$cells$background.color$data[,1] |> unique(), "#e1e1e1")
   expect_equal(fxResult$body$styles$cells$background.color$data[,2] |> unique(), "transparent")
 
@@ -161,8 +155,8 @@ test_that("fxTable", {
     title = "Title test 2",
     subtitle = "Subtitle for test 2",
     caption = "*This* is the caption",
-    groupNameCol = "group_level",
-    groupNameAsColumn = TRUE,
+    groupColumn = "group_level",
+    groupAsColumn = TRUE,
     groupOrder = c("cohort2", "cohort1")
   ))
 })
@@ -180,8 +174,8 @@ test_that("fxTable, test default styles and NULL", {
     title = "Test 1",
     subtitle = NULL,
     caption = NULL,
-    groupNameCol = NULL,
-    groupNameAsColumn = FALSE,
+    groupColumn = NULL,
+    groupAsColumn = FALSE,
     groupOrder = NULL
   )
 
@@ -216,8 +210,8 @@ test_that("fxTable, test default styles and NULL", {
     title = "Title test 2",
     subtitle = "Subtitle for test 2",
     caption = "*This* is the caption",
-    groupNameCol = "group_level",
-    groupNameAsColumn = FALSE,
+    groupColumn = "group_level",
+    groupAsColumn = FALSE,
     groupOrder = NULL
   )
 
@@ -241,7 +235,7 @@ test_that("fxTable, test default styles and NULL", {
   expect_equal(fxResult$body$styles$text$color$data[, "cdm_name"] |> unique(), "black")
 
   #Input 3: woring name style ----
-  expect_warning(
+  expect_message(
     fxResult <- fxTable(
       table_to_format,
       style = "heythere",
@@ -249,11 +243,10 @@ test_that("fxTable, test default styles and NULL", {
       title = "Title test 2",
       subtitle = "Subtitle for test 2",
       caption = "*This* is the caption",
-      groupNameCol = "group_level",
-      groupNameAsColumn = FALSE,
+      groupColumn = "group_level",
+      groupAsColumn = FALSE,
       groupOrder = NULL
-    ),
-    "does not correspon to any of our defined styles. Returning default."
+    )
   )
 })
 
@@ -269,8 +262,8 @@ test_that("fxTable, test colsToMergeRows", {
     title = "Title test 2",
     subtitle = "Subtitle for test 2",
     caption = "*This* is the caption",
-    groupNameCol = "group_level",
-    groupNameAsColumn = FALSE,
+    groupColumn = "group_level",
+    groupAsColumn = FALSE,
     groupOrder = NULL,
     colsToMergeRows = "all_columns"
   )
@@ -281,13 +274,13 @@ test_that("fxTable, test colsToMergeRows", {
   expect_equal(fxResult$body$styles$cells$border.color.top$data[,2],
                c("gray", "gray", "black", "black", "black", "black", "black", "black",
                  "gray", "gray", "black", "black", "black", "black", "black", "black"))
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,7],
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,4],
                c("gray", "gray", "gray", "black", "gray", "black", "black", "black",
                  "gray", "gray", "gray", "black", "gray", "black", "black", "black"))
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,8],
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,5],
                c("gray", "gray", "gray", "black", "gray", "black", "gray", "black",
                  "gray", "gray", "gray", "black", "gray", "black", "gray", "black"))
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,19],
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,16],
                c("gray", "gray", "gray", "gray", "gray", "gray", "gray", "gray",
                  "gray", "gray", "gray", "gray", "gray", "gray", "gray", "gray"))
 
@@ -299,8 +292,8 @@ test_that("fxTable, test colsToMergeRows", {
     title = "Title test 2",
     subtitle = "Subtitle for test 2",
     caption = "*This* is the caption",
-    groupNameCol = "group_level",
-    groupNameAsColumn = FALSE,
+    groupColumn = "group_level",
+    groupAsColumn = FALSE,
     groupOrder = NULL,
     colsToMergeRows = c("cdm_name", "variable_name")
   )
@@ -310,21 +303,21 @@ test_that("fxTable, test colsToMergeRows", {
   expect_equal(fxResult$body$styles$cells$border.color.top$data[,2],
                c("gray", "gray", "black", "black", "black", "black", "black", "black",
                  "gray", "gray", "black", "black", "black", "black", "black", "black"))
-  expect_equal(fxResult$body$styles$cells$border.color.top$data[,7],
+  expect_equal(fxResult$body$styles$cells$border.color.top$data[,4],
                c("gray", "gray", "gray", "black", "gray", "black", "black", "black",
                  "gray", "gray", "gray", "black", "gray", "black", "black", "black"))
 
   # Wroing input
-  expect_warning(fxTable(
+  expect_message(fxTable(
     table_to_format,
     style = "default",
     na = "-",
     title = "Title test 2",
     subtitle = "Subtitle for test 2",
     caption = "*This* is the caption",
-    groupNameCol = "group_level",
-    groupNameAsColumn = FALSE,
+    groupColumn = "group_level",
+    groupAsColumn = FALSE,
     groupOrder = NULL,
     colsToMergeRows = c("cdm_name", "lala")
-  ), "lala is not a column in the dataframe.")
+  ))
 })
