@@ -1,31 +1,9 @@
 test_that("tidy", {
-  mocksum <- mockSummarisedResult() |>
-  # settings
-  dplyr::union_all(
-    dplyr::tibble(
-      result_id = as.integer(1),
-      "cdm_name" = "mock",
-      "result_type" = "mock_summarised_result",
-      "package_name" = "visOmopResults",
-      "package_version" = utils::packageVersion("visOmopResults") |>
-        as.character(),
-      "group_name" = "overall",
-      "group_level" = "overall",
-      "strata_name" = "overall",
-      "strata_level" = "overall",
-      "variable_name" = "settings",
-      "variable_level" = NA_character_,
-      "estimate_name" = "mock_default",
-      "estimate_type" = "logical",
-      "estimate_value" = "TRUE",
-      "additional_name" = "overall",
-      "additional_level" = "overall"
-    )
-  )
+  mocksum <- mockSummarisedResult()
 
   expect_no_error(res0 <- tidy(x = mocksum, pivotEstimatesBy = "estimate_name"))
   expect_true(nrow(res0 |> dplyr::filter(.data$variable_name == "settings")) == 0)
-  expect_true(all(c("cohort_name", "age_group", "sex", "mock_default", "count",
+  expect_true(all(c("cohort_name", "age_group", "sex", "count",
                     "mean", "sd", "percentage") %in% colnames(res0)))
   expect_true(class(res0$percentage) == "numeric")
   expect_true(class(res0$mean) == "numeric")
@@ -34,18 +12,18 @@ test_that("tidy", {
   expect_no_error(res1 <- tidy(mocksum, splitGroup = FALSE, splitAdditional = FALSE,
                                splitStrata = FALSE, pivotEstimatesBy = c("variable_name", "variable_level", "estimate_name")))
   expect_true(all(c("group_name", "group_level", "strata_name", "strata_level",
-                    "additional_name", "additional_level", "mock_default") %in%
+                    "additional_name", "additional_level") %in%
                     colnames(res1)))
   expect_true(all(c("number subjects_NA_count", "age_NA_mean", "age_NA_sd", "Medications_Amoxiciline_count",
                     "Medications_Amoxiciline_percentage", "Medications_Ibuprofen_count",
-                    "Medications_Ibuprofen_percentage", "mock_default") %in% colnames(res1)))
+                    "Medications_Ibuprofen_percentage") %in% colnames(res1)))
 
-  expect_no_error(res2 <- tidy(mocksum |> dplyr::filter(variable_name != "settings"),
+  expect_no_error(res2 <- tidy(mocksum,
                                splitGroup = FALSE,
                                splitAdditional = FALSE,
+                               addSettings = FALSE,
                                pivotEstimatesBy = c("variable_name", "estimate_name"),
                                nameStyle = "{estimate_name}__{variable_name}"))
-  expect_false("mock_default" %in% colnames(res2))
   expect_false("logic__settings" %in% colnames(res2))
   expect_true(all(c("count__number subjects", "mean__age", "sd__age",
                     "count__Medications", "percentage__Medications") %in% colnames(res2)))
@@ -55,7 +33,9 @@ test_that("tidy", {
 
   expect_no_error(res3 <- tidy(mocksum, splitGroup = FALSE, splitAdditional = FALSE, splitStrata = FALSE,
                                 pivotEstimatesBy = NULL))
-  expect_true(all(colnames(res3) %in% c(colnames(mocksum), "mock_default")))
+  expect_true(all(colnames(res3) %in% c(
+    colnames(mocksum), "result_type", "package_name", "package_version"
+  )))
 
   # 2 id's:
   mocksum2 <- mocksum |>
@@ -67,10 +47,6 @@ test_that("tidy, dates", {
   result <- dplyr::tibble(
     "result_id" = integer(1),
     "cdm_name" = "mock",
-    "result_type" = "mock_summarised_result",
-    "package_name" = "visOmopResults",
-    "package_version" = utils::packageVersion("visOmopResults") |>
-      as.character(),
     "group_name" = "cohort_name",
     "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
     "strata_name" = rep(c(
@@ -92,10 +68,6 @@ test_that("tidy, dates", {
       dplyr::tibble(
         "result_id" = integer(1),
         "cdm_name" = "mock",
-        "result_type" = "mock_summarised_result",
-        "package_name" = "visOmopResults",
-        "package_version" = utils::packageVersion("visOmopResults") |>
-          as.character(),
         "group_name" = "cohort_name",
         "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
         "strata_name" = rep(c(
@@ -114,7 +86,15 @@ test_that("tidy, dates", {
         "additional_level" = "overall"
       )
     ) |>
-    omopgenerics::newSummarisedResult()
+    omopgenerics::newSummarisedResult(
+      settings = dplyr::tibble(
+        "result_id" = integer(1),
+        "result_type" = "mock_summarised_result",
+        "package_name" = "visOmopResults",
+        "package_version" = utils::packageVersion("visOmopResults") |>
+          as.character()
+      )
+    )
   expect_no_error(result_out <- tidy(result))
   expect_true(class(as.Date(result_out |> dplyr::pull(date))) == "Date")
 })
